# vim: set ts=4 sw=4 et:
# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/


%define		realname	mpc

Name:           mpclient
Version:        0.23
Release:        1.5
License:        GPL-3.0+
Summary:        A minimalist command line interface to MPD
Url:            http://www.musicpd.org/
Group:          Productivity/Multimedia/Sound/Utilities
Source:         http://www.musicpd.org/download/mpc/0/mpc-%{version}.tar.bz2
BuildRequires:  libmpdclient-devel >= 2.7
BuildRequires:  pkgconfig
Obsoletes:      %{realname} < %{version}
Provides:       %{realname} = %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
A client for MPD, the Music Player Daemon. mpc connects to a MPD
running on a machine via a network. Accepts input on standard input,
so can be easily used in scripts.

%prep
%setup -q -n %{realname}-%{version}

%build
%configure \
    	--with-default-host=127.0.0.1 \
    	--docdir=%{_docdir}/%{realname}

make %{?_smp_mflags}

%install
%makeinstall
install -m 0755 doc/mpd-pls-handler.sh %{buildroot}%{_bindir}/mpd-pls-handler
install -m 0755 doc/mpd-m3u-handler.sh %{buildroot}%{_bindir}/mpd-m3u-handler
install -m 0755 doc/mppledit %{buildroot}%{_bindir}/mppledit

mkdir -p %{buildroot}%{_sysconfdir}/bash_completion.d/
install -m 0644 doc/mpc-completion.bash %{buildroot}%{_sysconfdir}/bash_completion.d/mpc-completion.sh
rm -vf doc/mpc-completion.bash

%clean                                                                                                                  
%{?buildroot:rm -rf "%{buildroot}"}

%files
%defattr(-,root,root)
%dir %{_docdir}/mpc
%doc %{_docdir}/mpc/*
%{_bindir}/%{realname}
%{_bindir}/mpd-m3u-handler
%{_bindir}/mpd-pls-handler
%{_bindir}/mppledit
%{_sysconfdir}/bash_completion.d/mpc-completion.sh
%{_mandir}/man1/%{realname}.1*

%changelog
* Tue Jun 18 2013 fisiu@opensuse.org
- Update to 0.23:
  * do character set conversions on client-to-client messages
  * allow trailing slashes in paths that can be directories
  * make "mv" a shortcut for "move"
  * new command "cdprev"
  * support absolute paths in "add" and "update"
  * enable/disable: support output names, multiple arguments
    and "only" mode
  * doc: document missing format keywords
* Tue Feb  7 2012 pascal.bleser@opensuse.org
- update to 0.22:
  * implement the client-to-client protocol (MPD 0.17)
  * sticker: fix crash bug
  * print newline after volume level
  * print status after no-op relative volume change
- changes from 0.21:
  * idle: fix assertion failure on unknown idle event
  * new command "insert"
  * show only playlists on command "lsplaylists"
- changes from 0.20:
  * reactivate "search filename"
  * MixRamp support
  * support --format with "ls" and "listall"
  * new command "clearerror"
  * implement "current --wait"
  * command "add": print the failed song
* Thu Jan 14 2010 detlef@links2linux.de
- new upstream version <0.19>
  * require libmpdclient 2.2
  * reactivate "search filename"
  * MixRamp support
  * support --format with "ls" and "listall"
  * new command "clearerror"
  * implement "current --wait"
  * command "add": print the failed song
* Thu Dec 17 2009 detlef@links2linux.de
- rename to mpclient
* Mon Dec  7 2009 detlef@links2linux.de
- new upstream version <0.19>
  * search: fix "mpc search any"
  * idle: flush output after each idleloop iteration
  * added command "sticker" (MPD 0.15)
  * added command "replaygain" (MPD 0.16)
  * implemented position, id for --format
  * fixed bash completion
* Tue Aug 18 2009 detlef@links2linux.de
- new upstream version <0.17>
  * fixed busy loop while waiting for "idle" response
  * added command "idleloop"
* Thu Jul 23 2009 detlef@links2linux.de
- new upstream version <0.16>
  * added command "current"
  * support the new MPD modes "consume" and "single"
  * added command "idle"
* Mon Feb  2 2009 detlef@links2linux.de
- new upstream version <0.15>
  * optimized and simplified the "add" command, don't obtain and print
    song list when adding directories
  * same optimization for the "ls" command, which did some very
    expensive underscore matching logic using "listall"
  * show MPD error message in "status"
  * fixed special character handling in bash completion
  * fixed two crash bugs due to wrong string pool usage
  * don't fall back to ISO-Latin-1 in unknown locale
  * disable character set conversion to/from pipe
  * fix memory leak in songToFormatedString()
  * fix memory leak in charset_set()
  * Sat Dec 20 2008 - Detlef Reichelt <detlef@links2linux.de> <0.14>-<0.pm.1>
- new upstream version <0.14>
  * Support for date, genre, composer, performer, disc, and comment
  * Added "mpc find"
  * Added "mpc list"
* Tue Mar 27 2007 detlef@links2linux.de
- new upstream version
* Thu Sep 28 2006 detlef@links2linux.de
- new upstream version
* Mon Aug 21 2006 detlef@links2linux.de
- install file-handler
* Sun Aug 13 2006 detlef@links2linux.de
- new upstream version
* Tue Mar 23 2004 malakhanov@gmx.de
- modified for SUSE/Packman
* Wed Mar 10 2004 gbpeck@sbcglobal.net
- Update URL
- Rebuild for official release
* Mon Mar  8 2004 gbpeck@sbcglobal.net
- Version 0.10.1
* Wed Mar  3 2004 gbpeck@sbcglobal.net
- Version 0.10.0
* Fri Feb  6 2004 gbpeck@sbcglobal.net
- Rebuild with mach
* Thu Oct 30 2003 gbpeck@sbcglobal.net
- Version 0.9.2
* Tue Oct  7 2003 gbpeck@sbcglobal.net
- Version 0.9.1
* Tue Sep 30 2003 gbpeck@sbcglobal.net
- Version 0.9.0
* Thu Aug 14 2003 gbpeck@sbcglobal.net
- Initial build
